pub struct String<const LEN: usize>(/* private fields */);Expand description
Represents a fixed-length byte string.
This type can be created from a &str or &[u8] if their byte
length does not exceed the fixed length.
It can be freely converted from and to a [u8; N] array, and
to a Vec<u8> where it will be cut at the first null byte.
It can be converted to a Rust String if it is UTF8 encoded.
Implementations