WString

Struct WString 

pub struct WString<const LEN: usize>(/* private fields */);
Represents a fixed-length wide string.

This type can be created from a &[u16] if its length does not exceed the fixed length. It can be created from a &str if its length, encoded in UTF16, does not exceed the fixed length.

It can be freely converted from and to a [u16; N] array, and to a Vec<u16> where it will be cut at the first null.

It can be converted to a Rust String if it is properly UTF16 encoded.

Implementations

Source

impl<const LEN: usize> WString<LEN>

pub fn new() -> Self

Create a new empty string.

pub fn len(&self) -> usize

Return the number of code units up to the first null.

pub fn is_empty(&self) -> bool

pub fn as_slice(&self) -> &[u16]

Get the slice up to the first null code unit.

pub fn backing_array(&mut self) -> &mut [u16; LEN]

Get a reference to the full array of code units.