pub struct WString<const LEN: usize>(/* private fields */);Expand description
Represents a fixed-length wide string.
This type can be created from a &[u16] if its length does not
exceed the fixed length. It can be created from a &str if its
length, encoded in UTF16, does not exceed the fixed length.
It can be freely converted from and to a [u16; N] array, and
to a Vec<u16> where it will be cut at the first null.
It can be converted to a Rust String if it is properly UTF16
encoded.
Implementations